"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const exchangeUtils = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
const fmt = require('util').format;
const fse = require('fs-extra');
const os = require('os');
const _ = require('lodash');
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Copy extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetCopy = async (source, target, selectedOrganizationId) => {
            var _a, _b;
            const data = {};
            try {
                const src = exchangeUtils.assetSourceTargetValidator(source, selectedOrganizationId);
                const tgt = exchangeUtils.assetSourceTargetValidator(target, selectedOrganizationId);
                this.log(fmt('Copying asset from "%s" to "%s"', source, target));
                const { data: assetInfo } = await this.req.get(uris.v2Asset(src));
                const res = exchangeUtils.assetTypeValidator(assetInfo.type);
                if (typeof res === 'string') {
                    // eslint-disable-next-line unicorn/prefer-type-error
                    throw new Error(res);
                }
                tgt.name = assetInfo.name;
                tgt.description = assetInfo.description;
                tgt.contactName = assetInfo.contactName;
                tgt.contactEmail = assetInfo.contactEmail;
                tgt.apiVersion = assetInfo.productAPIVersion || assetInfo.versionGroup;
                const fileObj = exchangeUtils.getAssetMainFile(assetInfo);
                if (!fileObj) {
                    throw new Error('Asset has no files to be copied');
                }
                tgt.main = fileObj.mainFile;
                tgt.classifier = fileObj.classifier;
                tgt.organizationId = selectedOrganizationId;
                data.tmpFile = exchangeUtils.composeAssetFilePath(os.tmpdir(), fileObj);
                if (assetInfo.dependencies) {
                    tgt.dependencies = JSON.stringify(assetInfo.dependencies.map((dependency) => _.pick(dependency, ['groupId', 'assetId', 'version'])));
                }
                this.log('Downloading source asset data');
                await exchangeUtils.assetDownloadCommon(fileObj, data.tmpFile, this);
                this.log('Copying source asset data to target');
                const uriV2 = uris.v2Assets;
                await exchangeUtils.assetUploadRequest(this, tgt, data.tmpFile, uriV2);
                this.log('Asset copied');
                try {
                    fse.remove(data.tmpFile);
                }
                catch {
                    // Ignore
                }
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(Copy);
        await this.assetCopy(args.source, args.target, flags.targetOrganizationId || this.session.selectedOrganization.id);
    }
}
exports.default = Copy;
Copy.description = 'Copy an asset. ' + exchangeUtils.sourceTargetFormatMsg;
Copy.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    targetOrganizationId: core_1.Flags.string({ char: 't', description: 'Target organization id' }),
};
// .option('--targetOrganizationId <val>', 'Target organization id')
//   .types({string: ['source', 'target']})
Copy.args = [{ name: 'source', required: true }, { name: 'target', required: true }];
