"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class Describe extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetDescribe = async (assetIdentifier, selectedOrganizationId) => {
            var _a, _b;
            try {
                const asset = utils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                const url = uris.asset(asset);
                const res = await this.req.get(url);
                await this.showAsset(res.data);
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
        this.showAsset = async (asset) => {
            const table = [];
            table.push(['Name', asset.name], ['Changed', utils.fromNow(asset.modifiedAt)], ['Status', asset.status], ['Type', asset.type]);
            asset.productAPIVersion && table.push(['API Version', asset.productAPIVersion]);
            if (asset.productAPIVersions) {
                const productAPIVersions = asset.productAPIVersions.find((e) => e.productAPIVersion === asset.productAPIVersion);
                const versions = productAPIVersions ? productAPIVersions.versions : [{ version: asset.version }];
                table.push(['Asset Versions', versions.map((v) => {
                        return v.version;
                    }).join(', ')]);
                // eslint-disable-next-line unicorn/no-array-push-push
                table.push(['API Versions', asset.productAPIVersions.map((v) => {
                        return v.productAPIVersion;
                    }).join(', ')]);
            }
            else if (asset.versions) {
                table.push(['Asset Versions', asset.versions.map((v) => {
                        return v.version;
                    }).join(', ')]);
            }
            await this.show(table, asset);
        };
    }
    async run() {
        const { args } = await this.parse(Describe);
        await this.assetDescribe(args.assetIdentifier, this.session.selectedOrganization.id);
    }
}
exports.default = Describe;
Describe.description = 'Show a given asset\'s information. ' + utils.assetIdentifierFormatMsg;
Describe.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
Describe.args = [{ name: 'assetIdentifier',
        required: true,
    }];
