"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const exchangeUtils = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
const fmt = require('util').format;
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Download extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetDownload = async (assetIdentifier, directory) => {
            var _a, _b;
            try {
                const dir = anypoint_cli_command_1.utils.prepareDirectory(directory);
                const asset = exchangeUtils.assetIdentifierValidator(assetIdentifier, this.session.selectedOrganization.id);
                const { data: assetInfo } = await this.req.get(uris.asset(asset));
                const res = exchangeUtils.assetTypeValidator(assetInfo.type);
                if (typeof res === 'string') {
                    this.error(res);
                }
                const fileObj = exchangeUtils.getAssetMainFile(assetInfo);
                if (!fileObj) {
                    this.error('Asset has no files to be downloaded');
                }
                const fpath = exchangeUtils.composeAssetFilePath(dir, fileObj);
                this.log(fmt('Downloading asset to %s', fpath));
                await exchangeUtils.assetDownloadCommon(fileObj, fpath, this);
                this.log('Asset downloaded');
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(Download);
        await this.assetDownload(args.assetIdentifier, args.directory);
    }
}
exports.default = Download;
Download.description = 'Download an asset to the specified directory. ' + exchangeUtils.assetIdentifierFormatMsg;
Download.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    force: core_1.Flags.boolean({ char: 'f' }),
};
Download.args = [{ name: 'assetIdentifier' }, { name: 'directory' }];
