"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils = require("../../../helpers/utils");
const queries = require("../../../helpers/queries");
const flags_1 = require("../../../helpers/flags");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_2 = require("anypoint-cli-command/lib/core/flags");
class List extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetList = async (lmt, ofst, organizationId, searchText) => {
            var _a, _b, _c;
            try {
                const organizationIds = organizationId ? [organizationId] : undefined;
                const gqlVariables = {
                    limit: lmt,
                    offset: ofst,
                    organizationIds,
                    searchText,
                };
                const response = await this.queryGql(queries.GET_ASSETS, gqlVariables);
                if (response.errors) {
                    const msg = response.errors.map((error) => error.message).join(', ');
                    throw new Error(msg);
                }
                const assets = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.assets) ? response.data.assets : [];
                await this.show(utils.getAssetsTable(assets), assets);
            }
            catch (error) {
                ((_c = (_b = error.response) === null || _b === void 0 ? void 0 : _b.data) === null || _c === void 0 ? void 0 : _c.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(List);
        await this.assetList(flags.limit, flags.offset, flags.organizationId, args.searchText);
    }
}
exports.default = List;
List.description = 'Lists all assets';
List.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    organizationId: core_1.Flags.string({ description: 'Filter by organization id', default: '' }),
    limit: flags_1.limit,
    offset: flags_1.offset,
    ...flags_2.OutputFlag,
};
List.args = [{ name: 'searchText', default: '' }];
