"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
class Modify extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetModify = async (assetIdentifier, selectedOrganizationId, name, tags) => {
            var _a, _b;
            try {
                const asset = utils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                if (name)
                    return this.modifyName(asset, name);
                if (tags)
                    return this.modifyTags(asset, tags);
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
        this.modifyName = async (asset, name) => {
            this.log('Modifying asset name');
            const body = { name: name };
            await this.req.patch(uris.orgAssetMetadata(asset, this.session.selectedOrganization.id), body);
            this.log('Asset name modified');
        };
        this.modifyTags = async (asset, tags) => {
            this.log('Modifying asset tags');
            const tagsData = tags.split(',').map((tag) => {
                return {
                    value: tag,
                    key: tag,
                    mutable: true,
                };
            });
            const body = tagsData;
            await this.req.put(uris.assetTags(asset), body);
            this.log('Asset tags modified');
        };
    }
    async run() {
        const { args, flags } = await this.parse(Modify);
        await this.assetModify(args.assetIdentifier, this.session.selectedOrganization.id, flags.name, flags.tags);
    }
}
exports.default = Modify;
Modify.description = 'Modify an asset. ' + utils.assetIdentifierFormatMsg;
// .option('--name <val>', 'New asset name')
//   .option('--tags <tag1,tag2...tagN>', 'Asset comma-separated tags list')
Modify.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: core_1.Flags.string({ char: 'n', description: 'New asset name' }),
    tags: core_1.Flags.string({ char: 't', description: 'Asset comma-separated tags list' }),
};
Modify.args = [{ name: 'assetIdentifier',
        required: true,
    }];
