"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable unicorn/filename-case */
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const exchangeUtils = require("../../../helpers/utils");
const uris = require("../../../helpers/uris");
class MutableDataUpload extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.mutableDataUpload = async (flags, args) => {
            const asset = {
                organizationId: this.session.selectedOrganization.id,
                st: { ...exchangeUtils.assetIdentifierValidator(args.assetIdentifier, this.session.selectedOrganization.id) },
            };
            exchangeUtils.validateArgumentOptions(flags);
            const { categories = {}, fields = {}, tags, docs } = flags;
            const mainMetadata = tags ? { tags: tags } : {};
            const files = docs ? [{ classifier: 'docs', packaging: 'zip', path: docs }] : [];
            exchangeUtils.logProperties(this, asset, 'Asset');
            exchangeUtils.logProperties(this, mainMetadata, 'Asset tags');
            exchangeUtils.logProperties(this, categories, 'Asset categories');
            exchangeUtils.logProperties(this, fields, 'Asset fields');
            exchangeUtils.logProperties(this, files, 'Asset files');
            await exchangeUtils.asyncUploadRequest(this, this.uploadFunction, asset, mainMetadata, {}, files, fields, categories);
        };
        this.uploadFunction = async (asset, formData) => {
            try {
                const url = uris.mutableData(asset);
                const response = await this.req.patch(url, formData, { headers: {
                        ...formData.getHeaders(),
                        'x-from-service': exchangeUtils.X_FROM_SERVICE_HEADER,
                        'x-from-service-version': 'v2',
                    },
                });
                return response.data.mutableDataStatusLink;
            }
            catch (error) {
                this.error(error);
            }
        };
    }
    async run() {
        var _a, _b;
        const { args, flags } = await this.parse(MutableDataUpload);
        try {
            await this.mutableDataUpload(flags, args);
        }
        catch (error) {
            ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
        }
    }
}
exports.default = MutableDataUpload;
MutableDataUpload.description = 'Uploads mutable data (tags, categories, fields and documentation) to an already created asset. ' +
    'Basic example to upload mutable data: exchange asset mutableData --tags tag1,tag2 --categories.someKey someValue --docs /..../file-path/docs.zip asset-id/1.0.0. ' +
    'Describing the asset. ' + exchangeUtils.assetIdentifierFormatMsg + '\n' +
    'To learn more about the creation endpoint visit https://anypoint.mulesoft.com/exchange/portals/anypoint-platform/f1e97bc6-315a-4490-82a7-23abe036327a.anypoint-platform/exchange-experience-api/minor/2.0/pages/Asset%20Creation/';
MutableDataUpload.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    tags: core_1.Flags.string({ description: 'Tags. Should be used as a comma separated list. E.g. "tag1,tag2,tag3"' }),
    categories: core_1.Flags.string({ description: 'Categories. Should be used as --categories=\'{"someKey": "someValue"}\'', parse: JSON.parse }),
    fields: core_1.Flags.option({ description: 'Custom Fields. Should be used as --fields=\'{"someKey": "someValue"}\'', parse: JSON.parse }),
    docs: core_1.Flags.string({ description: 'Docs file. (Should specify the the "zip" file path. E.g. "--docs /.../file-path/docs.zip")' }),
};
MutableDataUpload.args = [{ name: 'assetIdentifier', required: true }, { name: 'properties' }];
