"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const exchangeUtils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const fmt = require('util').format;
class Delete extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetPageDelete = async (assetIdentifier, selectedOrganizationId, pageName) => {
            var _a, _b;
            try {
                const asset = exchangeUtils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                const path = await exchangeUtils.getAssetPagePath(asset, pageName, this);
                await exchangeUtils.putAssetInDraftMode(asset, this);
                this.log(fmt('Deleting asset page "%s"', path));
                const url = uris.assetDraftPage(asset, path);
                this.log('url', url);
                await this.req.delete(url);
                await exchangeUtils.publishAssetDraft(asset, this);
                this.log('Asset page deleted');
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(Delete);
        await this.assetPageDelete(args.assetIdentifier, this.session.selectedOrganization.id, args.pageName);
    }
}
exports.default = Delete;
Delete.description = 'Delete an asset\'s description page. ' + exchangeUtils.assetIdentifierFormatMsg;
Delete.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: core_1.Flags.string({ char: 'n', description: 'name to print' }),
    // flag with no value (-f, --force)
    force: core_1.Flags.boolean({ char: 'f' }),
};
Delete.args = [{ name: 'assetIdentifier',
        required: true,
    }, { name: 'pageName' }];
