"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const exchangeUtils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const fse = require('fs-extra');
const fmt = require('util').format;
const path = require('path');
class Download extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetPageDownload = async (assetIdentifier, selectedOrganizationId, directory, pageName) => {
            var _a, _b;
            try {
                await anypoint_cli_command_1.utils.prepareDirectory(directory);
                const asset = exchangeUtils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                const paths = await exchangeUtils.getAssetPagesPaths(asset, pageName, this);
                await Promise.all(paths.map(async (pagePath) => {
                    await this.downloadAssetPage(asset, pagePath, directory);
                }));
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ?
                    this.error(error.response.data.message) :
                    this.error(error);
            }
        };
        this.downloadAssetPage = async (asset, pagePath, directory) => {
            const fname = pagePath.slice(Math.max(0, pagePath.lastIndexOf('/') + 1));
            this.log(fmt('Downloading asset page "%s"', fname));
            const url = uris.assetPage(asset, pagePath);
            const config = { headers: { Accept: 'text/markdown' } };
            const { data } = await this.req.get(url, config);
            const fpath = path.join(directory, fmt('%s.md', fname));
            fse.writeFileSync(fpath, data || '');
        };
    }
    async run() {
        const { args } = await this.parse(Download);
        await this.assetPageDownload(args.assetIdentifier, this.session.selectedOrganization.id, args.directory, args.pageName);
    }
}
exports.default = Download;
Download.description = 'Download an asset\'s description page in Markdown format. ' +
    'When "pageName" is not specified, all pages are downloaded. ' +
    exchangeUtils.assetIdentifierFormatMsg;
Download.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
};
Download.args = [{ name: 'assetIdentifier',
        required: true,
    }, { name: 'directory', required: true }, { name: 'pageName' }];
