"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class List extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetPageList = async (assetIdentifier, selectedOrganizationId) => {
            var _a, _b;
            try {
                const asset = utils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                this.log('Getting asset pages list');
                const { data } = await this.req.get(uris.assetPages(asset));
                const tableHeader = ['Name', 'Path'];
                const tableData = [];
                tableData.push(tableHeader);
                for (const page of data) {
                    tableData.push([page.name, page.path]);
                }
                await this.show(tableData, data);
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ?
                    this.error(error.response.data.message) :
                    this.error(error);
            }
        };
    }
    async run() {
        const { args } = await this.parse(List);
        await this.assetPageList(args.assetIdentifier, this.session.selectedOrganization.id);
    }
}
exports.default = List;
List.description = 'List all pages for a given asset. ' + utils.assetIdentifierFormatMsg;
List.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    ...flags_1.OutputFlag,
};
List.args = [{ name: 'assetIdentifier',
        required: true,
    }];
