"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const exchangeUtils = require("../../../../helpers/utils");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const core_1 = require("@oclif/core");
const fmt = require('util').format;
class Modify extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetPageModify = async (assetIdentifier, selectedOrganizationId, pageName, name) => {
            var _a, _b;
            try {
                const asset = exchangeUtils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                await exchangeUtils.putAssetInDraftMode(asset, this);
                this.log(fmt('Renaming asset page "%s" to "%s"', pageName, name));
                await exchangeUtils.createAssetPage(this, asset, name, { 'x-move-source': pageName }, false);
                await exchangeUtils.publishAssetDraft(asset, this);
                this.log('Asset page modified');
            }
            catch (error) {
                ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(Modify);
        await this.assetPageModify(args.assetIdentifier, this.session.selectedOrganization.id, args.pageName, flags.name);
    }
}
exports.default = Modify;
Modify.description = 'Modify an asset\'s description page name. ' +
    'Renames page specified with --name to the new name <pageName>. ' +
    'The page name "home" makes a page the main description page. ' +
    exchangeUtils.assetIdentifierFormatMsg;
Modify.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: core_1.Flags.string({ char: 'n', required: true, description: 'New asset page name' }),
    // flag with no value (-f, --force)
    force: core_1.Flags.boolean({ char: 'f' }),
};
Modify.args = [{ name: 'assetIdentifier',
        required: true,
    }, { name: 'pageName', required: true }];
