"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const exchangeUtils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const core_2 = require("@oclif/core");
const fse = require('fs-extra');
const path = require('path');
const fmt = require('util').format;
class Download extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.getAssetPublishedResource = async (assetIdentifier, selectedOrganizationId, filepath, resourcePath) => {
            let rp;
            let dirPath;
            try {
                const asset = exchangeUtils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                rp = uris.assetPublishedResource(asset, resourcePath);
                dirPath = path.dirname(filepath);
            }
            catch (error) {
                this.error(error);
            }
            try {
                fse.accessSync(dirPath, fse.F_OK);
            }
            catch {
                this.error(`No such directory: ${dirPath}`);
            }
            try {
                core_2.CliUx.ux.action.start(fmt('Downloading resource... to %s', filepath));
                const response = await this.req.get(rp, { responseType: 'stream' });
                await anypoint_cli_command_1.utils.storeStreamingResp(response.data, filepath);
                this.log('Resource downloaded successfully...');
            }
            catch (error) {
                this.error(`Can't download resource: ${resourcePath}, error: ${error}`);
            }
            core_2.CliUx.ux.action.stop();
        };
    }
    async run() {
        const { args } = await this.parse(Download);
        await this.getAssetPublishedResource(args.assetIdentifier, this.session.selectedOrganization.id, args.filePath, args.resourcePath);
    }
}
exports.default = Download;
Download.description = 'Downloads the specified published resource (<resourcePath>) from the asset portal to <filePath>';
Download.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: core_1.Flags.string({ char: 'n', description: 'name to print' }),
    // flag with no value (-f, --force)
    force: core_1.Flags.boolean({ char: 'f' }),
};
Download.args = [{ name: 'assetIdentifier', required: true }, { name: 'resourcePath', required: true }, { name: 'filePath', required: true }];
