"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const utils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const flags_1 = require("anypoint-cli-command/lib/core/flags");
class List extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.assetResourcesList = async (assetIdentifier, selectedOrganizationId, draft) => {
            var _a, _b;
            try {
                const asset = utils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
                const { assetId, version } = asset;
                const request = draft ?
                    uris.assetDraftResources(asset) :
                    uris.assetPublishedResources(asset);
                const resourceStatus = (draft) ? 'draft' : 'published';
                this.log(`Getting asset ${resourceStatus} resource list\n`);
                const { data } = await this.req.get(request);
                const paths = data.map((resource) => resource.path);
                if (paths.length === 0) {
                    this.log(`The asset: "${assetId}/${version}" does not have any ${resourceStatus} resource`);
                }
                else {
                    const tableHeader = ['Resource Path'];
                    const tableData = [];
                    tableData.push(tableHeader);
                    for (const e of paths) {
                        tableData.push([e]);
                    }
                    await this.show(tableData, paths);
                }
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? this.error(error.response.data.message) : this.error(error);
            }
        };
    }
    async run() {
        const { args, flags } = await this.parse(List);
        await this.assetResourcesList(args.assetIdentifier, this.session.selectedOrganization.id, flags.draft);
    }
}
exports.default = List;
List.description = 'Lists published resources in the asset portal';
List.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    draft: core_1.Flags.boolean({ char: 'd', description: 'Lists draft resources in the asset portal', default: false }),
    ...flags_1.OutputFlag,
};
List.args = [{ name: 'assetIdentifier',
        required: true,
    }];
