"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const anypoint_cli_command_1 = require("anypoint-cli-command");
const utils = require("../../../../helpers/utils");
const uris = require("../../../../helpers/uris");
const fse = require('fs-extra');
const FormData = require('form-data');
class Upload extends anypoint_cli_command_1.AuthenticationBaseCommand {
    constructor() {
        super(...arguments);
        this.resourceUpload = async (assetIdentifier, selectedOrganizationId, filepath) => {
            let asset;
            try {
                asset = utils.assetIdentifierValidator(assetIdentifier, selectedOrganizationId);
            }
            catch (error) {
                this.error(error);
            }
            try {
                fse.accessSync(filepath, fse.F_OK);
            }
            catch {
                this.error(`No such file: ${filepath}`);
            }
            return this.resouceUploadRequest(asset, filepath);
        };
        this.resouceUploadRequest = async (asset, filepath) => {
            var _a, _b;
            const file = utils.buildFileFromFilepath(filepath);
            const fd = new FormData();
            fd.append(file.formDataKey, fse.createReadStream(utils.resolvePath(file.path)));
            let response;
            try {
                this.log('Uploading resource...');
                response = await this.req.post(uris.resourceUpload(asset), fd, { headers: {
                        ...fd.getHeaders(),
                        'x-from-service': utils.X_FROM_SERVICE_HEADER,
                        'x-from-service-version': 'v2'
                    },
                });
            }
            catch (error) {
                ((_b = (_a = error === null || error === void 0 ? void 0 : error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ?
                    this.error(error.response.data.message) :
                    this.error(error);
            }
            const responsePath = response.data.path;
            this.log('Resource uploaded. To use, add the following markdown code in the desired page:\n');
            this.log(`![${file.filename}](${responsePath})\n`);
            return { path: responsePath };
        };
    }
    async run() {
        const { args } = await this.parse(Upload);
        await this.resourceUpload(args.assetIdentifier, this.session.selectedOrganization.id, args.filepath);
    }
}
exports.default = Upload;
Upload.description = 'Upload a resource to an asset page' +
    `  Supported file extensions: ${utils.SUPPORTED_RESOURCES.join(', ')}`;
Upload.flags = {
    ...anypoint_cli_command_1.AuthenticationBaseCommand.flags,
    help: core_1.Flags.help({ char: 'h' }),
    // flag with a value (-n, --name=VALUE)
    name: core_1.Flags.string({ char: 'n', description: 'name to print' }),
    // flag with no value (-f, --force)
    force: core_1.Flags.boolean({ char: 'f' }),
};
Upload.args = [{ name: 'assetIdentifier', required: true }, { name: 'filepath', required: true }];
