"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteAssetResource = exports.assetPublishedResource = exports.assetDraftResources = exports.assetPublishedResources = exports.resourceUpload = exports.mainFiles = exports.assetPage = exports.assetDraftPage = exports.assetUndeprecate = exports.assetDeprecate = exports.assetDraftPortal = exports.orgAssetMetadata = exports.assetTags = exports.mutableData = exports.postAsset = exports.assetPages = exports.assetDraftPages = exports.v2Asset = exports.updateAssetStatus = exports.orgAsset = exports.asset = exports.v2Assets = exports.assets = void 0;
const fmt = require('util').format;
exports.assets = '/exchange/api/v1/assets';
exports.v2Assets = '/exchange/api/v2/assets';
const asset = (ast) => {
    return fmt('%s/%s/%s/%s', exports.assets, ast.groupId, ast.assetId, ast.version);
};
exports.asset = asset;
const orgAsset = (ast, selectedOrganizationId) => {
    return fmt('/exchange/api/v1/organizations/%s/assets/%s/%s/%s', selectedOrganizationId, ast.groupId, ast.assetId, ast.version);
};
exports.orgAsset = orgAsset;
const updateAssetStatus = (ast) => {
    return fmt('%s/status', (0, exports.v2Asset)(ast));
};
exports.updateAssetStatus = updateAssetStatus;
const v2Asset = (ast) => {
    return fmt(`${exports.v2Assets}/%s/%s/%s`, ast.groupId, ast.assetId, ast.version);
};
exports.v2Asset = v2Asset;
const assetDraftPages = (ast) => {
    return fmt('%s/portal/draft/pages', (0, exports.v2Asset)(ast));
};
exports.assetDraftPages = assetDraftPages;
const assetPages = (ast) => {
    return fmt('%s/portal/pages', (0, exports.v2Asset)(ast));
};
exports.assetPages = assetPages;
const postAsset = ({ organizationId, st }) => {
    return `/exchange/api/v2/organizations/${organizationId}/assets/${st.groupId}/${st.assetId}/${st.version}`;
};
exports.postAsset = postAsset;
const mutableData = ({ organizationId, st }) => {
    return `/exchange/api/v2/organizations/${organizationId}/assets/${st.groupId}/${st.assetId}/${st.version}/mutabledata`;
};
exports.mutableData = mutableData;
const assetTags = (assets) => {
    return fmt('%s/tags', (0, exports.asset)(assets));
};
exports.assetTags = assetTags;
const orgAssetMetadata = (ast, selectedOrganizationId) => {
    return fmt('%s/metadata', (0, exports.orgAsset)(ast, selectedOrganizationId));
};
exports.orgAssetMetadata = orgAssetMetadata;
const assetDraftPortal = (ast) => {
    return fmt('%s/portal/draft', (0, exports.v2Asset)(ast));
};
exports.assetDraftPortal = assetDraftPortal;
const assetDeprecate = (ast) => {
    const url = fmt('%s/status', (0, exports.v2Asset)(ast));
    return {
        url: url,
        body: {
            status: 'deprecated',
        },
    };
};
exports.assetDeprecate = assetDeprecate;
const assetUndeprecate = (ast) => {
    const url = fmt('%s/status', (0, exports.v2Asset)(ast));
    return {
        url: url,
        body: {
            status: 'published',
        },
    };
};
exports.assetUndeprecate = assetUndeprecate;
const assetDraftPage = (ast, pageName) => {
    return fmt('%s/%s', (0, exports.assetDraftPages)(ast), pageName);
};
exports.assetDraftPage = assetDraftPage;
const assetPage = (ast, pageName) => {
    return fmt('%s/%s', (0, exports.assetPages)(ast), pageName);
};
exports.assetPage = assetPage;
const mainFiles = (classifier) => {
    return `/exchange/api/v1/files/classifiers/${classifier}/entries/main`;
};
exports.mainFiles = mainFiles;
const resourceUpload = (ast) => {
    const apiV2 = (0, exports.v2Asset)(ast);
    return `${apiV2}/portal/draft/resources`;
};
exports.resourceUpload = resourceUpload;
const assetPublishedResources = (ast) => {
    const apiV2 = (0, exports.v2Asset)(ast);
    return `${apiV2}/portal/resources`;
};
exports.assetPublishedResources = assetPublishedResources;
const assetDraftResources = (ast) => {
    const apiV2 = (0, exports.v2Asset)(ast);
    return `${apiV2}/portal/draft/resources`;
};
exports.assetDraftResources = assetDraftResources;
const assetPublishedResource = (ast, resourcePath) => {
    const apiV2 = (0, exports.v2Asset)(ast);
    return `${apiV2}/portal/${resourcePath}`;
};
exports.assetPublishedResource = assetPublishedResource;
const deleteAssetResource = (ast, resourcePath) => {
    const apiV2 = (0, exports.v2Asset)(ast);
    return `${apiV2}/portal/draft/${resourcePath}`;
};
exports.deleteAssetResource = deleteAssetResource;
