"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.assetPageUpdate = exports.uploadAssetPage = exports.asyncUploadRequest = exports.waitUntilFinishPublication = exports.insertCustomProperties = exports.validateArgumentOptions = exports.logProperties = exports.assetDownloadCommon = exports.getAssetsTable = exports.assetUploadRequest = exports.composeAssetFilePath = exports.getAssetMainFile = exports.assetTypeValidator = exports.fromNow = exports.putAssetInDraftMode = exports.publishAssetDraft = exports.createAssetPage = exports.getAssetPagePath = exports.getAssetPagesPaths = exports.buildFileFromFilepath = exports.resolvePath = exports.assetSourceTargetValidator = exports.assetIdentifierValidator = exports.assetGAV = exports.SUPPORTED_RESOURCES = exports.X_FROM_SERVICE_HEADER = exports.supportedHeaders = exports.supportedTypes = exports.supportedClassifiers = exports.sourceTargetFormatMsg = exports.assetIdentifierFormatMsg = void 0;
/* eslint-disable no-await-in-loop */
const uris = require("./uris");
const path = require('path');
const os = require('os');
const anypoint_cli_command_1 = require("anypoint-cli-command");
const fmt = require('util').format;
const moment = require('moment');
const nodeUrl = require('url');
const fse = require('fs-extra');
const FormData = require('form-data');
exports.assetIdentifierFormatMsg = 'Argument "assetIdentifier" should be formatted as follows: ' +
    '([group_id]/)<asset_id>/<version>. ' +
    'If "group_id" is not specified, it will default ' +
    'to the currently selected Organization ID.';
exports.sourceTargetFormatMsg = 'Arguments "source" and "target" should be formatted as follows: ' +
    '([group_id]/)<asset_id>/<version>. ' +
    'If "group_id" is not specified, it will default ' +
    'to the currently selected Organization ID.';
exports.supportedClassifiers = ['oas', 'raml', 'wsdl', 'http', 'custom'];
exports.supportedTypes = ['rest-api', 'soap-api', 'http-api', 'raml-fragment', 'custom', 'connector', 'template', 'example', 'policy', 'app', 'extension', 'external-library'];
exports.supportedHeaders = ['assign-roles', 'x-user-id'];
exports.X_FROM_SERVICE_HEADER = 'anypoint-cli';
exports.SUPPORTED_RESOURCES = ['jpeg', 'jpg', 'jpe', 'gif', 'bmp', 'png', 'webp', 'ico', 'svg', 'tiff', 'tif'];
const assetGAV = (gav, selectedOrganizationId) => {
    if (gav.length === 2) {
        return {
            groupId: selectedOrganizationId,
            assetId: gav[0],
            version: gav[1],
        };
    }
    return {
        groupId: gav[0],
        assetId: gav[1],
        version: gav[2],
    };
};
exports.assetGAV = assetGAV;
const assetIdentifierValidator = (assetIdentifier, selectedOrganizationId) => {
    const parts = assetIdentifier.split('/');
    if (parts.length < 2) {
        throw new Error('`assetIdentifier` argument has an invalid format. ' +
            exports.assetIdentifierFormatMsg);
    }
    return (0, exports.assetGAV)(parts, selectedOrganizationId);
};
exports.assetIdentifierValidator = assetIdentifierValidator;
const assetSourceTargetValidator = (assetIdentifier, selectedOrganizationId) => {
    const parts = assetIdentifier.split('/');
    if (parts.length < 2) {
        throw new Error('`source` or `target` argument has an invalid format. ' +
            exports.sourceTargetFormatMsg);
    }
    return (0, exports.assetGAV)(parts, selectedOrganizationId);
};
exports.assetSourceTargetValidator = assetSourceTargetValidator;
const resolvePath = (filepath = '') => {
    if (filepath[0] === '~') {
        return path.join(os.homedir(), filepath.slice(1));
    }
    return filepath;
};
exports.resolvePath = resolvePath;
const buildFileFromFilepath = (filepath) => {
    const parsedPath = path.parse(filepath);
    const packaging = parsedPath.ext.slice(1);
    return {
        formDataKey: `files.${packaging}`,
        path: filepath,
        filename: parsedPath.name,
    };
};
exports.buildFileFromFilepath = buildFileFromFilepath;
const getAssetPagesPaths = async (asset, pageName, self) => {
    const url = uris.assetPages(asset);
    let { data } = await self.req.get(url);
    if (pageName) {
        data = data.filter((page) => page.name === pageName || page.path === pageName);
    }
    const paths = data.map((d) => d.path);
    return paths;
};
exports.getAssetPagesPaths = getAssetPagesPaths;
const getAssetPagePath = async (asset, pageName, self) => {
    const path = await (0, exports.getAssetPagesPaths)(asset, pageName, self);
    if (path.length === 0) {
        return Promise.reject(new Error('Unable to find page'));
    }
    return path[0];
};
exports.getAssetPagePath = getAssetPagePath;
const createAssetPage = async (self, asset, pageName, headers, ignoreConflict) => {
    var _a;
    try {
        self.log(fmt('Trying to create new asset page "%s"', pageName));
        ignoreConflict = ignoreConflict === undefined ? true : ignoreConflict;
        const config = {};
        if (headers !== undefined) {
            config.headers = headers;
        }
        const body = { pagePath: pageName };
        await self.req.post(uris.assetDraftPages(asset), body, config);
        self.log(fmt('Asset page "%s" created', pageName));
    }
    catch (error) {
        if (((_a = error.response) === null || _a === void 0 ? void 0 : _a.status) !== 409 || !ignoreConflict) {
            return Promise.reject(error);
        }
        self.log(fmt('Asset page named "%s" already exists', pageName));
    }
};
exports.createAssetPage = createAssetPage;
const publishAssetDraft = async (asset, self) => {
    self.log('Publishing asset draft');
    const url = uris.asset(asset);
    return self.req.patch(url);
};
exports.publishAssetDraft = publishAssetDraft;
const putAssetInDraftMode = async (asset, self) => {
    self.log('Enabling asset draft mode');
    const portalUrl = uris.assetDraftPortal(asset);
    return self.req.get(portalUrl);
};
exports.putAssetInDraftMode = putAssetInDraftMode;
const fromNow = (time) => {
    return moment.utc(time).fromNow();
};
exports.fromNow = fromNow;
const assetTypeValidator = (typ) => {
    const supportedAssetTypes = ['soap-api', 'custom', 'rest-api'];
    if (supportedAssetTypes.includes(typ)) {
        return true;
    }
    return fmt('Invalid asset type. Supported asset types are: %s', supportedAssetTypes.join(', '));
};
exports.assetTypeValidator = assetTypeValidator;
const getAssetMainFile = (assetInfo) => {
    // Map of asset types to their main file classifier (fat-raml is not included as it should never be a main file)
    const typeToClassifier = {
        'soap-api': ['wsdl'],
        custom: ['custom'],
        'rest-api': ['oas', 'raml'],
    };
    const files = assetInfo.files || [];
    return files.find(function (file) {
        if (typeToClassifier[assetInfo.type] === undefined)
            return;
        return typeToClassifier[assetInfo.type].includes(file.classifier) && !file.isGenerated;
    });
};
exports.getAssetMainFile = getAssetMainFile;
const composeAssetFilePath = (dir, fileObj) => {
    const pathname = (new nodeUrl.URL(fileObj.externalLink)).pathname;
    const fname = path.basename(pathname);
    return path.join(dir, fname);
};
exports.composeAssetFilePath = composeAssetFilePath;
const assetUploadRequest = (self, data, zipPath, url) => {
    const fd = new FormData();
    for (const key of Object.keys(data)) {
        if (data[key]) {
            fd.append(key, data[key]);
        }
    }
    // if (data.organizationId) {
    fd.append('organizationId', data.organizationId);
    // }
    // else {
    //   fd.append('organizationId', self.session.selectedOrganization.id)
    // }
    const config = { headers: {
            ...fd.getHeaders(),
            'x-from-service': exports.X_FROM_SERVICE_HEADER,
            'x-from-service-version': url.startsWith('/exchange/api/v2') ? 'v2' : 'v1',
        } };
    if (zipPath) {
        // const file = utils.buildFileFromFilepath(zipPath)
        fd.append('asset', fse.createReadStream((0, exports.resolvePath)(zipPath)));
    }
    return self.req.post(url, fd, config);
};
exports.assetUploadRequest = assetUploadRequest;
const getAssetsTable = (assets) => {
    const tableData = [];
    const header = ['GroupID', 'AssetID', 'Version', 'Name', 'Type', 'Changed'];
    tableData.push(header);
    for (const asset of assets) {
        const date = asset.updatedDate || asset.createdDate;
        const data = [
            asset.groupId,
            asset.assetId,
            asset.version,
            asset.name,
            asset.type,
            (0, exports.fromNow)(date),
        ];
        tableData.push(data);
    }
    return tableData;
};
exports.getAssetsTable = getAssetsTable;
const assetDownloadCommon = async (fileObj, fpath, self) => {
    const response = await self.req({ url: fileObj.externalLink, baseURL: '/', headers: {}, responseType: 'stream' });
    return anypoint_cli_command_1.utils.storeStreamingResp(response.data, fpath);
};
exports.assetDownloadCommon = assetDownloadCommon;
const logProperties = (self, properties, message, shouldJoin = false) => {
    if (message && properties) {
        self.log(message);
    }
    if (Array.isArray(properties)) {
        for (const property of properties) {
            (0, exports.logProperties)(self, { properties: JSON.stringify(property), shouldJoin: true });
        }
    }
    else if (shouldJoin) {
        const propertiesMap = Object.keys(properties).map(field => `${field}: ${properties[field]}`);
        self.log(`- ${propertiesMap.join(', ')}`);
    }
    else {
        for (const property of Object.keys(properties)) {
            self.log(`- ${property}: ${JSON.stringify(properties[property])}`);
        }
    }
};
exports.logProperties = logProperties;
const validateArgumentOptions = (options) => {
    if (!options || Object.keys(options).length === 0) {
        throw new Error('No arguments have been specified');
    }
};
exports.validateArgumentOptions = validateArgumentOptions;
const insertCustomProperties = (formData, tag, properties) => {
    try {
        for (const property of Object.keys(properties)) {
            formData.append(`${tag}.${property}`, properties[property]);
        }
    }
    catch (error) {
        throw new Error(`bad-formed '${tag}' flag : ${error.message}`);
    }
};
exports.insertCustomProperties = insertCustomProperties;
const getErrorMessage = (errorSteps) => {
    const stepWithErrors = errorSteps.find((errorStep) => (errorStep.errors && errorStep.errors.length > 0));
    if (!stepWithErrors) {
        return 'There was an unexpected error publishing the asset.';
    }
    const error = `There was an error publishing the asset
  - statusCode: ${stepWithErrors.statusCode},
  - message: ${stepWithErrors.errors.join(' ')}`;
    return stepWithErrors ? error : 'Unexpected error';
};
const waitUntilFinishPublication = async (self, publicationStatusLink) => {
    let response;
    let hasPublicationFinished = false;
    const stop = printSpinner('Waiting for the publication to finish');
    while (!hasPublicationFinished) {
        response = await self.req.get(publicationStatusLink);
        hasPublicationFinished = ['error', 'completed'].includes(response.data.status);
        // eslint-disable-next-line no-promise-executor-return
        await new Promise(resolve => setTimeout(resolve, 500));
    }
    stop();
    if ((response === null || response === void 0 ? void 0 : response.data.status) === 'error') {
        const errorMessage = getErrorMessage(response.data.steps);
        throw new Error(errorMessage);
    }
    self.log('Publishing completed');
};
exports.waitUntilFinishPublication = waitUntilFinishPublication;
const asyncUploadRequest = async (self, uploadFunction, asset, mainMetadata = {}, properties = {}, files = [], fields = {}, categories = {}, headers = {}) => {
    const formData = new FormData();
    for (const data of Object.keys(mainMetadata)) {
        formData.append(`${data}`, mainMetadata[data]);
    }
    (0, exports.insertCustomProperties)(formData, 'properties', properties);
    (0, exports.insertCustomProperties)(formData, 'fields', fields);
    (0, exports.insertCustomProperties)(formData, 'categories', categories);
    for (const file of files) {
        formData.append(`files.${file.classifier ? `${file.classifier}.` : ''}${file.packaging}`, fse.createReadStream((0, exports.resolvePath)(file.path)));
    }
    let publicationStatusLink;
    try {
        publicationStatusLink = await uploadFunction(asset, formData, headers);
    }
    catch (error) {
        return Promise.reject(error);
    }
    await (0, exports.waitUntilFinishPublication)(self, publicationStatusLink);
    return publicationStatusLink;
};
exports.asyncUploadRequest = asyncUploadRequest;
const uploadAssetPage = async (asset, pageName, mdPath, self) => {
    self.log('Uploading asset page');
    const config = { headers: { 'Content-Type': 'text/markdown' },
        json: false };
    const body = fse.readFileSync(mdPath);
    const url = uris.assetDraftPage(asset, pageName);
    return self.req.put(url, body, config);
};
exports.uploadAssetPage = uploadAssetPage;
const assetPageUpdate = async (assetIdentifier, orgId, pageName, mdPath, createPage, self) => {
    var _a, _b;
    self.log('Updating asset page');
    try {
        const asset = (0, exports.assetIdentifierValidator)(assetIdentifier, orgId);
        await (0, exports.putAssetInDraftMode)(asset, self);
        if (createPage) {
            await (0, exports.createAssetPage)(self, asset, pageName);
        }
        await (0, exports.uploadAssetPage)(asset, pageName, mdPath, self);
        await (0, exports.publishAssetDraft)(asset, self);
        self.log('Asset page uploaded and published');
    }
    catch (error) {
        ((_b = (_a = error.response) === null || _a === void 0 ? void 0 : _a.data) === null || _b === void 0 ? void 0 : _b.message) ? self.error(error.response.data.message) : self.error(error);
    }
};
exports.assetPageUpdate = assetPageUpdate;
function printSpinner(message) {
    let i = 0;
    const spinner = ['-', '\\', '|', '/'];
    const interval = setInterval(() => {
        process.stdout.write(`\r${message} ` + spinner[i]);
        i = (i + 1) % spinner.length;
    }, 250);
    return () => {
        process.stdout.write('\n');
        clearInterval(interval);
    };
}
